@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.104_04';
+our $VERSION = '0.105_01';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -1681,7 +1681,7 @@ sub _set_operational_status {
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Sun Sep  2 23:31:25 2018 GMT
+# on Fri Sep  7 13:39:46 2018 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1768,7 +1768,7 @@ __PACKAGE__->status( add => 25471, iridium => 'D', 'Iridium 77', 'Decayed 2017-0
 __PACKAGE__->status( add => 25527, iridium => '-', 'Iridium 2', 'Tumbling' );
 __PACKAGE__->status( add => 25528, iridium => 'S', 'Iridium 86', '' );
 __PACKAGE__->status( add => 25529, iridium => 'D', 'Iridium 85', 'Decayed 2000-12-30' );
-__PACKAGE__->status( add => 25530, iridium => '+', 'Iridium 84', '' );
+__PACKAGE__->status( add => 25530, iridium => 'S', 'Iridium 84', '' );
 __PACKAGE__->status( add => 25531, iridium => '+', 'Iridium 83', '' );
 __PACKAGE__->status( add => 25577, iridium => 'S', 'Iridium 20', '' );
 __PACKAGE__->status( add => 25578, iridium => 'S', 'Iridium 11', '' );
@@ -1783,8 +1783,8 @@ __PACKAGE__->status( add => 27450, iridium => 'S', 'Iridium 97', '' );
 __PACKAGE__->status( add => 27451, iridium => 'D', 'Iridium 98', 'Decayed 2018-08-24' );
 
 # Summary:
-# Operational [+]: 14
-#       Spare [S]: 14
+# Operational [+]: 13
+#       Spare [S]: 15
 #    Tumbling [-]: 34
 #     Decayed [D]: 35
 
